#!/bin/sh
set -o errexit

###
# Copyright (©) 2015-2022, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Darksiders 2
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220116.5

# Set game-specific variables

GAME_ID='darksiders-2'
GAME_NAME='Darksiders Ⅱ'

ARCHIVE_BASE_0='setup_darksiders2_deathinitive_2.1.0.4.exe'
ARCHIVE_BASE_0_MD5='5b39f665a8367f4ebe7c845b2ebbac81'
ARCHIVE_BASE_0_TYPE='rar'
ARCHIVE_BASE_0_PART1='setup_darksiders2_deathinitive_2.1.0.4-1.bin'
ARCHIVE_BASE_0_PART1_MD5='ec9c85b15f23b79bd87668282b8101ed'
ARCHIVE_BASE_0_PART1_TYPE='rar'
ARCHIVE_BASE_0_PART2='setup_darksiders2_deathinitive_2.1.0.4-2.bin'
ARCHIVE_BASE_0_PART2_MD5='4eb87fd00792a0e35b0abd8b7bc124e0'
ARCHIVE_BASE_0_PART2_TYPE='rar'
ARCHIVE_BASE_0_PART3='setup_darksiders2_deathinitive_2.1.0.4-3.bin'
ARCHIVE_BASE_0_PART3_MD5='113f5a09d0289db3b1c5a5f85a82849e'
ARCHIVE_BASE_0_PART3_TYPE='rar'
ARCHIVE_BASE_0_PART4='setup_darksiders2_deathinitive_2.1.0.4-4.bin'
ARCHIVE_BASE_0_PART4_MD5='ca12e47f9cce195b09a66c7ff27121ab'
ARCHIVE_BASE_0_PART4_TYPE='rar'
ARCHIVE_BASE_0_SIZE='16000000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.1.0.4'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/darksiders_ii_deathinitive_edition'

CONTENT_PATH_DEFAULT='game'
ARCHIVE_DOC_DATA_FILES='
manual.pdf'
ARCHIVE_GAME_BIN_FILES='
darksiders2.exe
*.dll'
ARCHIVE_GAME_DATA_MEDIA_FILES='
media/media.upak'
ARCHIVE_GAME_DATA_SOUNDS_FILES='
media/sounds_streamed'
ARCHIVE_GAME_DATA_FILES='
darksiders2.dsl
media'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='darksiders2.exe'
APP_MAIN_ICON='darksiders2.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA_MEDIA PKG_DATA_SOUNDS PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_DATA_MEDIA_ID="${PKG_DATA_ID}-media"
PKG_DATA_MEDIA_DESCRIPTION="$PKG_DATA_DESCRIPTION - media"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_MEDIA_ID"

PKG_DATA_SOUNDS_ID="${PKG_DATA_ID}-sounds"
PKG_DATA_SOUNDS_DESCRIPTION="$PKG_DATA_DESCRIPTION - sounds"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_SOUNDS_ID"

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
config:users/${USER}/AppData/Local/Darksiders2
saves:users/${USER}/Documents/My Games/Darksiders2'
CONFIG_DIRS='./config'
DATA_DIRS='./saves'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Enable dxvk patches in the WINE prefix

# shellcheck disable=SC1004
APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Install dxvk on first launch
if [ ! -e dxvk_installed ]; then
	# Wait until the WINE prefix creation is complete
	printf "Waiting for the WINE prefix initialization to complete, it might take a couple seconds…\n"
	while [ ! -f "${WINEPREFIX}/system.reg" ]; do
		sleep 1s
	done

	if \
		command -v dxvk-setup >/dev/null 2>&1 && \
		command -v wine-development >/dev/null 2>&1
	then
		dxvk-setup install --development
		touch dxvk_installed
	elif command -v winetricks >/dev/null 2>&1; then
		winetricks dxvk
		touch dxvk_installed
	else
		message="\\033[1;33mWarning:\\033[0m\\n"
		message="${message}DXVK patches could not be installed in the WINE prefix.\\n"
		message="${message}The game might run with display or performance issues.\\n"
		printf "\\n${message}\\n"
	fi

	# Wait a bit to ensure there is no lingering wine process
	sleep 1s
fi'
case "$OPTION_PACKAGE" in
	('deb')
		# Debian-based distributions should use repositories-provided dxvk
		# winetricks is used as a fallback for branches not having access to dxvk-setup
		extra_dependencies='mesa-vulkan-drivers | vulkan-icd, dxvk-wine64-development | winetricks, dxvk | winetricks'
		if [ -n "$PKG_BIN_DEPS_DEB" ]; then
			PKG_BIN_DEPS_DEB="${PKG_BIN_DEPS_DEB}, ${extra_dependencies}"
		else
			PKG_BIN_DEPS_DEB="$extra_dependencies"
		fi
	;;
	(*)
		# Default is to use winetricks
		PKG_BIN_DEPS="${PKG_BIN_DEPS} winetricks"
	;;
esac

# Extract game data

archive_part1_path=$(realpath --canonicalize-existing "$SOURCE_ARCHIVE_PART1")
archive_part2_path=$(realpath --canonicalize-existing "$SOURCE_ARCHIVE_PART2")
archive_part3_path=$(realpath --canonicalize-existing "$SOURCE_ARCHIVE_PART3")
archive_part4_path=$(realpath --canonicalize-existing "$SOURCE_ARCHIVE_PART4")
game_id=$(game_id)
ln --symbolic "$archive_part1_path" "${PLAYIT_WORKDIR}/${game_id}.r00"
ln --symbolic "$archive_part2_path" "${PLAYIT_WORKDIR}/${game_id}.r01"
ln --symbolic "$archive_part3_path" "${PLAYIT_WORKDIR}/${game_id}.r02"
ln --symbolic "$archive_part4_path" "${PLAYIT_WORKDIR}/${game_id}.r03"
(
	ARCHIVE='SOURCE_ARCHIVE_PART1'
	SOURCE_ARCHIVE_PART1="${PLAYIT_WORKDIR}/${game_id}.r00"
	extract_data_from "$SOURCE_ARCHIVE_PART1"
)
rm \
	"${PLAYIT_WORKDIR}/${game_id}.r00" \
	"${PLAYIT_WORKDIR}/${game_id}.r01" \
	"${PLAYIT_WORKDIR}/${game_id}.r02" \
	"${PLAYIT_WORKDIR}/${game_id}.r03"
tolower "${PLAYIT_WORKDIR}/gamedata"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "${PLAYIT_WORKDIR}"

# Print instructions

print_instructions

exit 0
