#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Heroes Chronicles 5
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220807.1

GAME_ID_COMMON='heroes-chronicles'
GAME_NAME_COMMON='Heroes Chronicles'

GAME_ID="${GAME_ID_COMMON}-5"
GAME_NAME="${GAME_NAME_COMMON}: Chapter 5 - The World Tree"

ARCHIVE_BASE_0='setup_heroes_chronicles_chapter5_2.1.0.42.exe'
ARCHIVE_BASE_0_MD5='57b3ec588e627a2da30d3bc80ede5b1d'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='470000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.1.0.42'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/heroes_chronicles_all_chapters'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_GAME_BIN_FILES='
the?world?tree/*.asi
the?world?tree/*.dll
the?world?tree/*.exe'
ARCHIVE_GAME_DATA_FILES='
the?world?tree/data
the?world?tree/games
the?world?tree/maps'
ARCHIVE_GAME_COMMON_FILES='
data
mp3'
ARCHIVE_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/the world tree"
ARCHIVE_DOC_DATA_FILES='
*.pdf
*.txt'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='the world tree/worldtree.exe'
APP_MAIN_ICON='the world tree/worldtree.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA PKG_COMMON'

PKG_COMMON_ID="${GAME_ID_COMMON}-common"
PKG_COMMON_DESCRIPTION='common files'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'
PKG_DATA_DEPS="$PKG_COMMON_ID"

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

USER_PERSISTENT_DIRECTORIES='
the world tree/games
the world tree/maps'
USER_PERSISTENT_FILES='
*.lod'

# Set up a WINE virtual desktop on first launch, using the current desktop resolution

PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks xrandr sed"
sed_expression='s/.*primary.* ([0-9]+x[0-9]+).*/\1/p'
sed_options="--regexp-extended --silent --expression='$sed_expression'"
APP_WINETRICKS="$APP_WINETRICKS vd=\$(LANG=C xrandr | sed $sed_options)"

# Run the game binary from its parent directory

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Run the game binary from its parent directory
cd "$(dirname "$APP_EXE")"
APP_EXE=$(basename "$APP_EXE")'

# Allow to skip intro video on first launch + set default settings

app_path="C:\\\\${GAME_ID}\\\\the world tree\\\\"
registry_dump_settings_file='registry-dumps/default-settings.reg'
registry_dump_settings_content='Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\Software\New World Computing\Heroes Chronicles\WorldTree]
"Animate SpellBook"=dword:00000001
"AppPath"="'"${app_path}"'"
"Autosave"=dword:00000001
"Bink Video"=dword:00000000
"Blackout Computer"=dword:00000000
"Combat Army Info Level"=dword:00000000
"Combat Auto Creatures"=dword:00000001
"Combat Auto Spells"=dword:00000001
"Combat Ballista"=dword:00000001
"Combat Catapult"=dword:00000001
"Combat First Aid Tent"=dword:00000001
"Combat Shade Level"=dword:00000000
"Combat Speed"=dword:00000000
"Computer Walk Speed"=dword:00000003
"First Time"=dword:00000000
"Last Music Volume"=dword:00000005
"Last Sound Volume"=dword:00000005
"Main Game Full Screen"=dword:00000001
"Main Game Show Menu"=dword:00000001
"Main Game X"=dword:0000000a
"Main Game Y"=dword:0000000a
"Move Reminder"=dword:00000001
"Music Volume"=dword:00000005
"Quick Combat"=dword:00000000
"Show Combat Grid"=dword:00000000
"Show Combat Mouse Hex"=dword:00000000
"Show Intro"=dword:00000001
"Show Route"=dword:00000001
"Sound Volume"=dword:00000005
"Test Blit"=dword:00000000
"Test Decomp"=dword:00000000
"Test Read"=dword:00000000
"Town Outlines"=dword:00000001
"Video Subtitles"=dword:00000001
"Walk Speed"=dword:00000002
"Window Scroll Speed"=dword:00000001
'
ARCHIVE_GAME_BIN_FILES="$ARCHIVE_GAME_BIN_FILES
$registry_dump_settings_file"
APP_REGEDIT="$APP_REGEDIT $registry_dump_settings_file"
SCRIPT_DEPS="$SCRIPT_DEPS iconv"

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Set path used for data shared between all Heroes Chronicles games

case "$OPTION_PACKAGE" in
	('arch')
		PATH_GAME_COMMON="${OPTION_PREFIX}/share/${GAME_ID_COMMON}"
	;;
	('deb')
		PATH_GAME_COMMON="${OPTION_PREFIX}/share/games/${GAME_ID_COMMON}"
	;;
	('gentoo'|'egentoo')
		PATH_GAME_COMMON="${OPTION_PREFIX}/share/${GAME_ID_COMMON}"
	;;
	(*)
		error_option_invalid 'package' "$OPTION_PACKAGE"
	;;
esac

# Use a common directory and symbolic links to handle data shared between all Heroes Chronicles games

PKG_DATA_POSTINST_RUN="$PKG_DATA_POSTINST_RUN
# Link common files shared by the games series
ln --symbolic '${PATH_GAME_COMMON}/data' '${PATH_GAME}'
ln --symbolic '${PATH_GAME_COMMON}/mp3' '${PATH_GAME}'"
PKG_DATA_PRERM_RUN="$PKG_DATA_PRERM_RUN
# Delete links to common files shared by the games series
rm '${PATH_GAME}/data'
rm '${PATH_GAME}/mp3'"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

(
	content_path=$(content_path_default)
	cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"

	# Allow to skip intro video on first launch + set default settings
	mkdir --parents "$(dirname "$registry_dump_settings_file")"
	printf '%s' "$registry_dump_settings_content" | iconv \
		--from-code=UTF-8 --to-code=UTF-16 \
		--output="$registry_dump_settings_file"
)

# Include game icon

PKG='PKG_DATA'
icons_inclusion

# Include game data

PKG='PKG_COMMON'
organize_data 'GAME_COMMON' "$PATH_GAME_COMMON"

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata 'PKG_DATA' 'PKG_BIN'
(
	GAME_ID="$GAME_ID_COMMON"
	GAME_NAME="$GAME_NAME_COMMON"
	write_metadata 'PKG_COMMON'
)
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
