#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 Mopi
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Sherlock Holmes Versus Jack the Ripper
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220508.2

# Set game-specific variables

GAME_ID='sherlock-holmes-versus-jack-the-ripper'
GAME_NAME='Sherlock Holmes Versus Jack the Ripper'

ARCHIVE_BASE_0='setup_sherlock_holmes_vs_jack_the_ripper_2.0.0.2.exe'
ARCHIVE_BASE_0_MD5='65d2d3ee20a5d4db4017c90701ab91cd'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent --lowercase --gog'
ARCHIVE_BASE_0_PART1='setup_sherlock_holmes_vs_jack_the_ripper_2.0.0.2-1.bin'
ARCHIVE_BASE_0_PART1_MD5='17c054477fe1fe12e79513ae71ff1a5d'
ARCHIVE_BASE_0_PART1_TYPE='rar'
ARCHIVE_BASE_0_PART2='setup_sherlock_holmes_vs_jack_the_ripper_2.0.0.2-2.bin'
ARCHIVE_BASE_0_PART2_MD5='26eebfcd9a171eb3a380876681803597'
ARCHIVE_BASE_0_PART2_TYPE='rar'
ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.2'
ARCHIVE_BASE_0_SIZE='3200000'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/sherlock_holmes_versus_jack_the_ripper'

CONTENT_PATH_DEFAULT='game'
ARCHIVE_GAME_BIN_FILES='
*.dll
*.exe'
ARCHIVE_GAME_L10N_EN_FILES='
000/en.pak
000/sounds_en.pak'
ARCHIVE_GAME_L10N_FR_FILES='
000/fr.pak
000/sounds_fr.pak'
ARCHIVE_GAME_DATA_FILES='
logo
data.txt
shaders.0050
splash_screen.jpg
000/game.pak
000/sounds.pak
000/texture.pak
000/texture3d.pak'
ARCHIVE_GAME0_BIN_PATH='support/app'
ARCHIVE_GAME0_BIN_FILES='
user.ini'

CONFIG_FILES='*.ini'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='game.exe'
APP_MAIN_ICON='game.exe'
APP_MAIN_ICON_WRESTOOL_OPTIONS='--type=14 --language=0'

PACKAGES_LIST='PKG_BIN PKG_L10N_EN PKG_L10N_FR PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_L10N_ID="${GAME_ID}-l10n"

PKG_L10N_EN_ID="${PKG_L10N_ID}-en"
PKG_L10N_EN_PROVIDE="$PKG_L10N_ID"
PKG_L10N_EN_DESCRIPTION='English localization'

PKG_L10N_FR_ID="${PKG_L10N_ID}-fr"
PKG_L10N_FR_PROVIDE="$PKG_L10N_ID"
PKG_L10N_FR_DESCRIPTION='French localization'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="${PKG_DATA_ID} ${PKG_L10N_ID} wine"

# Use persistent storage for saved games

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/${USER}/Application Data/Games/sherlock holmes versus jack the ripper/save
saves:users/${USER}/Application Data/Games/sherlock holmes contre jack l'\''eventreur/save'
DATA_DIRS="$DATA_DIRS ./saves"

# Install PhysX in the WINE prefix
# Provided installers can not be used:
# - with PhysX-9.13.0604-SystemSoftware-Legacy.msi, the game fails to load PhysX
# - with PhysX-9.15.0428-SystemSoftware.exe, PhysX installation fails

PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"
APP_WINETRICKS="$APP_WINETRICKS physx"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction "$ARCHIVE"
prepare_package_layout

# Include language-specific configuration file

(
	content_path=$(content_path_default)
	cd "${PLAYIT_WORKDIR}/gamedata"

	PKG='PKG_L10N_EN'
	package_path=$(package_get_path "$PKG")
	source_file="${content_path}/_loc/en"
	destination_file="${package_path}${PATH_GAME}/game.ini"
	mkdir --parents "$(dirname "$destination_file")"
	mv "$source_file" "$destination_file"

	PKG='PKG_L10N_FR'
	package_path=$(package_get_path "$PKG")
	source_file="${content_path}/_loc/fr"
	destination_file="${package_path}${PATH_GAME}/game.ini"
	mkdir --parents "$(dirname "$destination_file")"
	mv "$source_file" "$destination_file"
)

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

case "${LANG%_*}" in
	('fr')
		lang_string='version %s :'
		lang_en='anglaise'
		lang_fr='française'
	;;
	('en'|*)
		lang_string='%s version:'
		lang_en='English'
		lang_fr='French'
	;;
esac
printf '\n'
printf "$lang_string" "$lang_en"
print_instructions 'PKG_L10N_EN' 'PKG_DATA' 'PKG_BIN'
printf "$lang_string" "$lang_fr"
print_instructions 'PKG_L10N_FR' 'PKG_DATA' 'PKG_BIN'

exit 0
