#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2022, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Syberia 2
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220102.1

# Set game-specific variables

GAME_ID='syberia-2'
GAME_NAME='Syberia Ⅱ'

ARCHIVE_BASE_EN_0='setup_syberia_2_20171109_(16283).exe'
ARCHIVE_BASE_EN_0_MD5='f33e25fa29810e9ff8c6f009b7fdec3b'
ARCHIVE_BASE_EN_0_TYPE='innosetup'
ARCHIVE_BASE_EN_0_SIZE='1600000'
ARCHIVE_BASE_EN_0_VERSION='1.0-gog16283'
ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/syberia_2'

ARCHIVE_BASE_FR_0='setup_syberia_2_french_20171109_(16283).exe'
ARCHIVE_BASE_FR_0_MD5='e53a1ad01440837b933e935522389ab8'
ARCHIVE_BASE_FR_0_TYPE='innosetup'
ARCHIVE_BASE_FR_0_SIZE='1600000'
ARCHIVE_BASE_FR_0_VERSION='1.0-gog16283'
ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/syberia_2'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_L10N_FILES='
*.pdf
*.txt'
ARCHIVE_GAME_BIN_FILES='
*.dll
*.exe
dlls
launch'
ARCHIVE_GAME_L10N_FILES='
data/minimalres.syb
data/string.dat'
ARCHIVE_GAME_DATA_FILES='
cmo
data
splash
video'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='game.exe'
APP_MAIN_ICON='syberia2.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1"

# Localization

PACKAGES_LIST="PKG_L10N $PACKAGES_LIST"
PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_BIN_DEPS="$PKG_BIN_DEPS $PKG_L10N_ID"

## English

PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_DESCRIPTION_EN='English localization'

## French

PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_DESCRIPTION_FR='French localization'

# Use persistent storage for user data

CONFIG_FILES='./launch/settings.ini'
APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/${USER}/Documents/Syberia 2 Saves'
DATA_DIRS='./saves'

# Set up a WINE virtual desktop on first launch, using the current desktop resolution

sed_expression='s/.*primary.* ([0-9]+x[0-9]+).*/\1/p'
sed_options="--regexp-extended --silent --expression='${sed_expression}'"
APP_WINETRICKS="${APP_WINETRICKS} vd=\$(LANG=C xrandr | sed ${sed_options})"
PKG_BIN_DEPS="${PKG_BIN_DEPS} winetricks xrandr sed"

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Set game language

case "$ARCHIVE" in
	('ARCHIVE_BASE_FR_'*)
		language='FR'
	;;
	('ARCHIVE_BASE_EN_'*|*)
		language='AN'
	;;
esac
PKG='PKG_L10N'
package_path=$(package_get_path "$PKG")
registry_file='registry-tweaks/lang.reg'
APP_REGEDIT="$APP_REGEDIT $registry_file"
registry_file_path="${package_path}${PATH_GAME}/${registry_file}"
registry_file_directory=$(dirname "$registry_file_path")
mkdir --parents "$registry_file_directory"
{
	cat <<- 'EOF'
	Windows Registry Editor Version 5.00
	
	[HKEY_LOCAL_MACHINE\SOFTWARE\Microids\Syberia DVD]
	EOF
	cat <<- EOF
	"Language"="${language}"
	EOF
} > "$registry_file_path"

# Work around a crash on nvidia drivers
# cf. https://bugs.winehq.org/show_bug.cgi?id=43199
#     https://bugs.winehq.org/show_bug.cgi?id=44009

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
registry_file='registry-tweaks/no-xvidmode.reg'
APP_REGEDIT="$APP_REGEDIT $registry_file"
registry_file_path="${package_path}${PATH_GAME}/${registry_file}"
registry_file_directory=$(dirname "$registry_file_path")
mkdir --parents "$registry_file_directory"
cat > "$registry_file_path" << 'EOF'
Windows Registry Editor Version 5.00

[HKEY_CURRENT_USER\Software\Wine\X11 Driver]
"UseXVidMode"="N"
EOF

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
