#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2019 Emmanuel Gil Peyrot <linkmauve@linkmauve.fr>
# SPDX-FileCopyrightText: © 2020 BetaRays
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Touhou 11
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220805.1

GAME_ID='touhou-11-demo'
GAME_NAME='Touhou Chireiden ~ Subterranean Animism (demo)'

ARCHIVE_BASE_0='th11tr002a_setup.exe'
ARCHIVE_BASE_0_MD5='9b7c092a529fcc1f48590f0a2b3cca87'
ARCHIVE_BASE_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent'
ARCHIVE_BASE_0_SIZE='140000'
ARCHIVE_BASE_0_VERSION='0.02a-zun1'
ARCHIVE_BASE_0_URL='https://www16.big.or.jp/~zun/html/th11top.html'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='
*.txt
マニュアル'
ARCHIVE_GAME_BIN_FILES='
*.exe'
ARCHIVE_GAME_DATA_FILES='
*.dat'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='th11.exe'
APP_MAIN_ICON='th11.exe'

APP_CONFIG_ID="${GAME_ID}-config"
APP_CONFIG_NAME="$GAME_NAME - configuration"
APP_CONFIG_CAT='Settings'
APP_CONFIG_TYPE='wine'
APP_CONFIG_EXE='custom.exe'
APP_CONFIG_ICON='th11.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1"
PKG_BIN_DEPS_DEB='fonts-wqy-microhei'
PKG_BIN_DEPS_ARCH='wqy-microhei'
PKG_BIN_DEPS_GENTOO='media-fonts/wqy-microhei'

# Set appropriate locale before running the game

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Set appropriate locale before running the game
export LANG=ja_JP.UTF-8'
APP_CONFIG_PRERUN="$APP_MAIN_PRERUN"

# Use persistent storage for user data

USER_PERSISTENT_FILES='
h11.cfg
scoreth11.dat
log.txt'

# convmv and iconv are used to convert files encoding

SCRIPT_DEPS="$SCRIPT_DEPS convmv iconv"

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Check for broken version of innoextract

if [ "$(innoextract --version | head -n1)" = 'innoextract 1.8' ]
then
	case "${LANG%_*}" in
		('fr')
			message='Votre version dʼinnoextract peut rencontrer des problèmes de compatibilité avec cette archive.\n'
			message="$message"'Voir %s\n\n'
			url='https://forge.dotslashplay.it/play.it/doc/-/wikis/user/tools/fr/innoextract#innoextract-18-sur-les-archives-japonaises'
		;;
		('en'|*)
			message='This version of innoextract can break when processing this archive.\n'
			message="$message"'Please see %s\n\n'
			url='https://forge.dotslashplay.it/play.it/doc/-/wikis/user/tools/innoextract#innoextract-18-on-japanese-archives'
		;;
	esac
	print_warning
	printf "$message" "$url"
fi

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

(
	content_path=$(content_path_default)
	cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"
	
	# Convert the file names and text files to UTF-8 encoding
	convmv -f UTF-8 -t WINDOWS-1252 --notest -r . >/dev/null
	convmv -f CP932 -t UTF-8 --notest -r . >/dev/null
	iconv_shell_command='contents=$(iconv --from-code CP932 --to-code UTF-8 "$1")'
	iconv_shell_command="$iconv_shell_command"'; printf "%s" "$contents" > "$1"'
	find . \( -name '*.txt' -o -name '*.html' \) -exec \
		sh -c "$iconv_shell_command" -- '{}' \;
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
